/****************************************************************************
	This file is part of Basqet.

	Basqet is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	Basqet is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
    along with Basqet.  If not, see <http://www.gnu.org/licenses/>.

****************************************************************************/

#include "cmdsettag.h"

#include "notedata.h"

#include <QString>

CmdSetTag::CmdSetTag(NoteData* subject, QString tag)
		:mSubject(subject),
		mTag(tag)
{
	if (mSubject)
	{
		QString sameFamily = mSubject->getTagBySameFamily(tag);

		if (mSubject->hasTag(mTag))
		{
			mAction = ClearTag;

		}
		else if (!sameFamily.isEmpty())
		{
			mAction = ChangeTag;
			mOldTag = sameFamily;


		}
		else
		{
			mAction = SetTag;
		}

	}
}


void CmdSetTag::redo()
{
	switch(mAction)
	{
		case ClearTag:
			mSubject->clearTagValue(mTag);;
			break;

		case ChangeTag:
			mSubject->replaceTag(mOldTag, mTag);
			break;

		case SetTag:
			mSubject->setTagValue(mTag);
			break;
	}

}

void CmdSetTag::undo()
{
	switch(mAction)
	{
		case ClearTag:
			mSubject->setTagValue(mTag);
			break;

		case ChangeTag:
			mSubject->replaceTag(mTag, mOldTag);
			break;

		case SetTag:
			mSubject->clearTagValue(mTag);
			break;
	}
}
