/****************************************************************************
	This file is part of Basqet.

	Basqet is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	Basqet is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
    along with Basqet.  If not, see <http://www.gnu.org/licenses/>.

****************************************************************************/

#include "pagenotewidgeteventfilter.h"

#include <QMouseEvent>


PageNoteWidgetEventFilter::PageNoteWidgetEventFilter()
		: mMoveIsOngoing(false)
{
}



bool PageNoteWidgetEventFilter::eventFilter(QObject *obj, QEvent *event)
{
	if (!mMoveIsOngoing)
	{
		// User is starting the move-operation.
		if (event->type() == QEvent::MouseMove)
		{
			QMouseEvent* mouseEvent = static_cast<QMouseEvent *>(event);
			emit startMouseMoveEvent(mouseEvent);

			mMoveIsOngoing = true;

			return true;
		}
		else
		{
			return obj->eventFilter(obj, event);
		}
	}
	else
	{
		// USer continues the move operations.
		if (event->type() == QEvent::MouseMove)
		{
			QMouseEvent* mouseEvent = static_cast<QMouseEvent *>(event);
			emit mouseMoveEvent(mouseEvent);

			return true;
		}
		// User releases the button and move-operation is finished.
		else if (event->type() == QEvent::MouseButtonRelease)
		{
			QMouseEvent* mouseEvent = static_cast<QMouseEvent *>(event);
			emit mouseMoveEventEnd(mouseEvent);

			mMoveIsOngoing = false;

			return true;
		}
		else
		{
			return obj->eventFilter(obj, event);
		}
	}

}

